@@ -504,7 +504,7 @@ void QCGTopLevel::createActions()
 
     _layoutDup = new QAction(tr("&Duplicate"), this);
     connect(_layoutDup, &QAction::triggered, this, &QCGTopLevel::layoutDuplicate);
-    _layoutDup->setShortcut(Qt::CTRL + Qt::Key_Plus);
+    _layoutDup->setShortcut(Qt::CTRL | Qt::Key_Plus);
     _layoutDup->setStatusTip(tr("Duplicate current layout"));
 
     _layoutRemove = new QAction(tr("&Remove"), this);
@@ -513,12 +513,12 @@ void QCGTopLevel::createActions()
 
     _layoutNext = new QAction(tr("Go to &Next"), this);
     connect(_layoutNext, &QAction::triggered, this, &QCGTopLevel::layoutNext);
-    _layoutNext->setShortcut(Qt::CTRL + Qt::Key_Right);
+    _layoutNext->setShortcut(Qt::CTRL | Qt::Key_Right);
     _layoutNext->setStatusTip(tr("Switch to next layout"));
 
     _layoutPrev = new QAction(tr("Go to &Previous"), this);
     connect(_layoutPrev, &QAction::triggered, this, &QCGTopLevel::layoutPrevious);
-    _layoutPrev->setShortcut(Qt::CTRL + Qt::Key_Left);
+    _layoutPrev->setShortcut(Qt::CTRL | Qt::Key_Left);
     _layoutPrev->setStatusTip(tr("Switch to previous layout"));
 
     _layoutRestore = new QAction(tr("&Restore to Default"), this);
@@ -532,7 +532,7 @@ void QCGTopLevel::createActions()
     // go menu actions
     icon = QApplication::style()->standardIcon(QStyle::SP_ArrowUp);
     _upAction = new QAction(icon, tr( "Up" ), this );
-    _upAction->setShortcut( QKeySequence(Qt::ALT+Qt::Key_Up) );
+    _upAction->setShortcut( QKeySequence(Qt::ALT | Qt::Key_Up) );
     _upAction->setStatusTip(tr("Go Up in Call Stack"));
     _upAction->setMenu(new QMenu(this));
     connect(_upAction->menu(), &QMenu::aboutToShow,
@@ -544,7 +544,7 @@ void QCGTopLevel::createActions()
 
     icon = QApplication::style()->standardIcon(QStyle::SP_ArrowBack);
     _backAction = new QAction(icon, tr("Back"), this);
-    _backAction->setShortcut( QKeySequence(Qt::ALT+Qt::Key_Left) );
+    _backAction->setShortcut( QKeySequence(Qt::ALT | Qt::Key_Left) );
     _backAction->setStatusTip(tr("Go Back"));
     _backAction->setMenu(new QMenu(this));
     connect(_backAction->menu(), &QMenu::aboutToShow,
@@ -556,7 +556,7 @@ void QCGTopLevel::createActions()
 
     icon = QApplication::style()->standardIcon(QStyle::SP_ArrowForward);
     _forwardAction = new QAction(icon, tr("Forward"), this);
-    _forwardAction->setShortcut( QKeySequence(Qt::ALT+Qt::Key_Right) );
+    _forwardAction->setShortcut( QKeySequence(Qt::ALT | Qt::Key_Right) );
     _forwardAction->setStatusTip(tr("Go Forward"));
     _forwardAction->setMenu(new QMenu(this));
     connect(_forwardAction->menu(), &QMenu::aboutToShow,
@@ -574,7 +574,7 @@ void QCGTopLevel::createActions()
 
     // window menu actions
     _minimizeAction = new QAction(tr("&Minimize"), this);
-    _minimizeAction->setShortcut(Qt::CTRL + Qt::Key_M);
+    _minimizeAction->setShortcut(Qt::CTRL | Qt::Key_M);
     connect(_minimizeAction, &QAction::triggered, this, &QWidget::showMinimized);
 
     _zoomAction = new QAction(tr("&Zoom"), this);
@@ -955,7 +955,7 @@ void QCGTopLevel::exportGraph()
 }
 
 
-bool QCGTopLevel::setEventType(QString s)
+void QCGTopLevel::setEventType(QString s)
 {
     EventType* ct;
 
@@ -964,17 +964,17 @@ bool QCGTopLevel::setEventType(QString s)
     // if costtype with given name not found, use first available
     if (!ct && _data) ct = _data->eventTypes()->type(0);
 
-    return setEventType(ct);
+    setEventType(ct);
 }
 
-bool QCGTopLevel::setEventType2(QString s)
+void QCGTopLevel::setEventType2(QString s)
 {
     EventType* ct;
 
     // Special type tr("(Hidden)") gives 0
     ct = (_data) ? _data->eventTypes()->type(s) : nullptr;
 
-    return setEventType2(ct);
+    setEventType2(ct);
 }
 
 void QCGTopLevel::eventTypeSelected(const QString& s)
@@ -993,9 +993,10 @@ void QCGTopLevel::eventType2Selected(const QString& s)
     setEventType2(ct);
 }
 
-bool QCGTopLevel::setEventType(EventType* ct)
+void QCGTopLevel::setEventType(EventType* ct)
 {
-    if (_eventType == ct) return false;
+    if (_eventType == ct) return;
+
     _eventType = ct;
 
     if (ct) {
@@ -1009,13 +1010,12 @@ bool QCGTopLevel::setEventType(EventType* ct)
     _multiView->setEventType(_eventType);
 
     updateStatusBar();
-
-    return true;
 }
 
-bool QCGTopLevel::setEventType2(EventType* ct)
+void QCGTopLevel::setEventType2(EventType* ct)
 {
-    if (_eventType2 == ct) return false;
+    if (_eventType2 == ct) return;
+
     _eventType2 = ct;
 
     _partSelection->setEventType2(_eventType2);
@@ -1024,8 +1024,6 @@ bool QCGTopLevel::setEventType2(EventType* ct)
     _multiView->setEventType2(_eventType2);
 
     updateStatusBar();
-
-    return true;
 }
 
 
@@ -1385,8 +1383,8 @@ void QCGTopLevel::updateEventTypeMenu(QMenu* m, bool secondary)
     }
 
     if (secondary) {
-        connect(m, SIGNAL(triggered(QAction*)),
-                this, SLOT(setEventType2(QAction*)), Qt::UniqueConnection);
+        connect(m, &QMenu::triggered,
+                this, qOverload<QAction*>(&QCGTopLevel::setEventType2), Qt::UniqueConnection);
 
         if (_eventType2 != nullptr) {
             action = m->addAction(tr("Hide"));
@@ -1395,8 +1393,8 @@ void QCGTopLevel::updateEventTypeMenu(QMenu* m, bool secondary)
         }
     }
     else {
-        connect(m, SIGNAL(triggered(QAction*)),
-                this, SLOT(setEventType(QAction*)), Qt::UniqueConnection);
+        connect(m, &QMenu::triggered,
+                this, qOverload<QAction*>(&QCGTopLevel::setEventType), Qt::UniqueConnection);
     }
 
     EventTypeSet* ets = _data->eventTypes();
@@ -1440,9 +1438,10 @@ void QCGTopLevel::addEventTypeMenu(QMenu* popup, bool withCost2)
                          this, SLOT(setRelativeCost()));
 }
 
-bool QCGTopLevel::setEventType(QAction* action)
+void QCGTopLevel::setEventType(QAction* action)
 {
-    if (!_data) return false;
+    if (!_data) return;
+
     int id = action->data().toInt(nullptr);
 
     EventTypeSet* m = _data->eventTypes();
@@ -1450,12 +1449,14 @@ bool QCGTopLevel::setEventType(QAction* action)
     if (id >=100 && id<199) ct = m->realType(id-100);
     if (id >=200 && id<299) ct = m->derivedType(id-200);
 
-    return ct ? setEventType(ct) : false;
+    if (ct)
+        setEventType(ct);
 }
 
-bool QCGTopLevel::setEventType2(QAction* action)
+void QCGTopLevel::setEventType2(QAction* action)
 {
-    if (!_data) return false;
+    if (!_data) return;
+
     int id = action->data().toInt(nullptr);
 
     EventTypeSet* m = _data->eventTypes();
@@ -1463,7 +1464,7 @@ bool QCGTopLevel::setEventType2(QAction* action)
     if (id >=100 && id<199) ct = m->realType(id-100);
     if (id >=200 && id<299) ct = m->derivedType(id-200);
 
-    return setEventType2(ct);
+    setEventType2(ct);
 }
 
 void QCGTopLevel::addGoMenu(QMenu* popup)
